@@ -5,7 +5,15 @@ This module implements basic functionality to query npm registry for security ad
 """
 import logging
 
-import orjson
+try:
+    import orjson
+
+    ORJSON_AVAILABLE = True
+except ImportError:
+    import json
+
+    ORJSON_AVAILABLE = False
+
 import requests
 
 from vdb.lib import config as config
@@ -23,6 +31,8 @@ logging.basicConfig(
 )
 LOG = logging.getLogger(__name__)
 
+json_lib = orjson if ORJSON_AVAILABLE else json
+
 
 class NpmSource(NvdSource):
     """
@@ -67,8 +77,7 @@ class NpmSource(NvdSource):
         return self.convert(json_data)
 
     def download_recent(self, local_store=True):
-        """Method which downloads the recent CVE
-        """
+        """Method which downloads the recent CVE"""
         url = config.npm_advisories_url + "?perPage=100&page=1"
         r = requests.get(url=url)
         if r.ok:
@@ -80,8 +89,7 @@ class NpmSource(NvdSource):
         return None
 
     def download_all(self, local_store=True):
-        """Download all historic cve data
-        """
+        """Download all historic cve data"""
         data_list = []
         url = config.npm_advisories_url + "?perPage=100&page=1"
         for y in range(0, int(config.npm_pages_count)):
@@ -185,6 +193,9 @@ class NpmSource(NvdSource):
             )
             if v.get("references"):
                 references = convert_md_references(v.get("references"))
+            references = json_lib.dumps(references)
+            if isinstance(references, bytes):
+                references = references.decode("utf-8", "ignore")
             severity = v.get("severity")
             vendor = "npm"
             product = v["module_name"]
@@ -223,11 +234,12 @@ class NpmSource(NvdSource):
                     "version_end_excluding", ""
                 )
                 description = fix_text(description)
+
                 tdata = config.CVE_TPL % dict(
                     cve_id=cve_id,
                     cwe_id=cwe_id,
                     assigner=assigner,
-                    references=orjson.dumps(references).decode("utf-8"),
+                    references=references,
                     description="",
                     vectorString=vectorString,
                     vendor=vendor,
@@ -249,10 +261,10 @@ class NpmSource(NvdSource):
                     lastModifiedDate=lastModifiedDate,
                 )
                 try:
-                    vuln = NvdSource.convert_vuln(orjson.loads(tdata))
+                    vuln = NvdSource.convert_vuln(json_lib.loads(tdata))
                     vuln.description = description
                     ret_data.append(vuln)
-                except Exception:
-                    pass
+                except Exception as e:
+                    LOG.debug(e)
                 vr = vr + 1
         return ret_data
