@@ -3,7 +3,15 @@ import gzip
 import logging
 import tempfile
 
-import orjson
+try:
+    import orjson
+
+    ORJSON_AVAILABLE = True
+except ImportError:
+    import json
+
+    ORJSON_AVAILABLE = False
+
 import requests
 
 from vdb.lib import CvssV3, Vulnerability, VulnerabilityDetail, VulnerabilitySource
@@ -24,6 +32,8 @@ download_chunk_size = 128
 # Create database
 db = dbLib.get()
 
+json_lib = orjson if ORJSON_AVAILABLE else json
+
 
 def get_version(inc_version, exc_version):
     """
@@ -38,12 +48,10 @@ def get_version(inc_version, exc_version):
 
 
 class NvdSource(VulnerabilitySource):
-    """NVD CVE source. This uses CVE json 1.1 format that are split based on the year
-    """
+    """NVD CVE source. This uses CVE json 1.1 format that are split based on the year"""
 
     def download_all(self, local_store=True):
-        """Download all historic cve data
-        """
+        """Download all historic cve data"""
         data_list = []
         for y in range(now.year, int(start_year) - 1, -1):
             data = self.fetch(y)
@@ -53,16 +61,14 @@ class NvdSource(VulnerabilitySource):
         return data_list
 
     def download_recent(self, local_store=True):
-        """Method which downloads the recent CVE gzip from NVD
-        """
+        """Method which downloads the recent CVE gzip from NVD"""
         data = self.fetch("recent")
         if local_store:
             self.store(data)
         return data
 
     def fetch(self, year):
-        """Private Method which downloads the given CVE gzip from NVD
-        """
+        """Private Method which downloads the given CVE gzip from NVD"""
         url = config.nvd_url % dict(year=year)
         LOG.debug("Download NVD CVE from {}".format(url))
         with tempfile.NamedTemporaryFile() as tf:
@@ -73,15 +79,14 @@ class NvdSource(VulnerabilitySource):
             with gzip.open(tf.name, "rb") as gzipjf:
                 cve_data = gzipjf.read()
                 try:
-                    json_data = orjson.loads(cve_data)
+                    json_data = json_lib.loads(cve_data)
                     return self.convert(json_data)
                 except Exception:
                     logging.warning("Exception while parsing NVD CVE feed")
                     return None
 
     def convert(self, cve_data):
-        """Convert cve data to Vulnerability
-        """
+        """Convert cve data to Vulnerability"""
         items = cve_data.get("CVE_Items")
         data = []
         for cve_item in items:
@@ -95,8 +100,7 @@ class NvdSource(VulnerabilitySource):
         return self.download_all()
 
     def store(self, data):
-        """Store data in the database
-        """
+        """Store data in the database"""
         docs = dbLib.store(db, data)
         return docs
 
@@ -123,6 +127,9 @@ class NvdSource(VulnerabilitySource):
         severity = None
         base_score = None
         description = vuln["cve"]["description"]["description_data"][0]["value"]
+        # Issue 12 - Ignore disputed vulnerabilities
+        if "** DISPUTED **" in description:
+            return None
         rdata = vuln["cve"]["references"]["reference_data"]
         related_urls = [r["url"] for r in rdata]
         if "baseMetricV3" in vuln["impact"]:
